HookServer class

Inheritance

Constructors

HookServer(int port, [String host = '0.0.0.0'])

Properties

hashCode → int
The hash code for this object.
no setterinherited
host → String
final
onEvent → Stream<HookEvent>
no setterinherited
port → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

handleHookRequest(HttpRequest request) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() → void
stop() → Future
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited