IssueEvent class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

IssueEvent({String? action, User? assignee, IssueLabel? label, Issue? issue, User? sender, Repository? repository})
IssueEvent.fromJson(Map<String, dynamic> input)
factory

Properties

action ↔ String?
getter/setter pair
assignee ↔ User?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
issue ↔ Issue?
getter/setter pair
label ↔ IssueLabel?
getter/setter pair
repository ↔ Repository?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender ↔ User?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited